==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/plugins/desktop_docking/translations/desktop_docking_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it">
<context>
    <name>@default</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Tray</source>
        <translation>Barra</translation>
    </message>
    <message>
        <source>Desktop Docking</source>
        <translation>Desktop MInimizzato</translation>
    </message>
    <message>
        <source>Horizontal position</source>
        <translation>Posizione Orizzontale</translation>
    </message>
    <message>
        <source>Vertical position</source>
        <translation>Posizione verticale</translation>
    </message>
    <message>
        <source>Transparent</source>
        <translation>Trasparente</translation>
    </message>
    <message>
        <source>Background color</source>
        <translation>Colore di sfondo</translation>
    </message>
    <message>
        <source>Enable Move entry in docklet&apos;s menu</source>
        <translation>Abilita lo spostamento ingressi nel menu minimizzato</translation>
    </message>
    <message>
        <source>Move</source>
        <translation>Sposta</translation>
    </message>
    <message>
        <source>Enable icon moving on desktop. After pressing move cursor over docking icon and then move. Press any mouse key when the icon is in right place.</source>
        <translation>Abilita spostamento icone sul desktop</translation>
    </message>
</context>
<context>
    <name>DesktopDock</name>
    <message>
        <source>Move</source>
        <translation>Sposta</translation>
    </message>
</context>
</TS>

==> kadu_1.0.orig.tar.bz2: kadu-1.0/plugins/desktop_docking/translations/desktop_docking_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Tray</source>
        <translation>Barra</translation>
    </message>
    <message>
        <source>Desktop Docking</source>
        <translation>Desktop MInimizzato</translation>
    </message>
    <message>
        <source>Horizontal position</source>
        <translation>Posizione Orizzontale</translation>
    </message>
    <message>
        <source>Vertical position</source>
        <translation>Posizione verticale</translation>
    </message>
    <message>
        <source>Transparent</source>
        <translation>Trasparente</translation>
    </message>
    <message>
        <source>Background color</source>
        <translation>Colore di sfondo</translation>
    </message>
    <message>
        <source>Enable Move entry in docklet&apos;s menu</source>
        <translation>Abilita lo spostamento ingressi nel menu minimizzato</translation>
    </message>
    <message>
        <source>Move</source>
        <translation>Sposta</translation>
    </message>
    <message>
        <source>Enable icon moving on desktop. After pressing move cursor over docking icon and then move. Press any mouse key when the icon is in right place.</source>
        <translation>Abilita spostamento icone sul desktop</translation>
    </message>
    <message>
        <source>Buddies list</source>
        <translation>Lista contatti</translation>
    </message>
</context>
<context>
    <name>DesktopDock</name>
    <message>
        <source>Move</source>
        <translation>Sposta</translation>
    </message>
</context>
</TS>
